#
# spec file for package python-watchdog
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-watchdog
Version:        0.10.2
Release:        bp155.2.13
Summary:        Filesystem events monitoring
License:        Apache-2.0
URL:            https://github.com/gorakhargosh/watchdog
Source:         https://files.pythonhosted.org/packages/source/w/watchdog/watchdog-%{version}.tar.gz
BuildRequires:  %{python_module pathtools >= 0.1.1}
BuildRequires:  %{python_module pytest-timeout >= 0.3}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
Requires:       python-PyYAML
Requires:       python-argh
Requires:       python-pathtools >= 0.1.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Python API and shell utilities to monitor file system events.

%package doc
Summary:        Documentation and examples for %{name}

%description doc
This package contains documentation and examples for %{name}.

%prep
%setup -q -n watchdog-%{version}
chmod -x README.rst
# Remove all shebangs
find src -name "*.py" | xargs sed -i -e '/^#!\//, 1d'

%build
%python_build
cd docs && make html && rm -r build/html/.buildinfo build/html/objects.inv # Build HTML docs

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/watchmedo
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
sed -i '/--cov/d' setup.cfg
export LANG=en_US.UTF-8
# test_event_dispatcher randomly fails on SLE15
%pytest -k 'not test_event_dispatcher'

%post
%python_install_alternative watchmedo

%postun
%python_uninstall_alternative watchmedo

%files %{python_files}
%license COPYING LICENSE
%doc AUTHORS changelog.rst MANIFEST.in README.rst
%python_alternative %{_bindir}/watchmedo
%{python_sitelib}/watchdog
%{python_sitelib}/watchdog-%{version}-py%{python_version}.egg-info

%files %{python_files doc}
%doc docs/build/html

%changelog
* Wed Jun  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip randomly failing test test_event_dispatcher
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Mar 10 2020 pgajdos@suse.com
- version update to 0.10.2
  - Fixed the ``build_ext`` command on macOS Catalina (`#628 <https://github.com/gorakhargosh/watchdog/pull/628>`__)
  - Fixed the installation of macOS requirements on non-macOS OSes (`#635 <https://github.com/gorakhargosh/watchdog/pull/635>`__)
  - Refactored ``dispatch()`` method of ``FileSystemEventHandler``,
    ``PatternMatchingEventHandler`` and ``RegexMatchingEventHandler``
  - [bsd] Improved tests support on non Windows/Linux platforms (`#633 <https://github.com/gorakhargosh/watchdog/pull/633>`__, `#639 <https://github.com/gorakhargosh/watchdog/pull/639>`__)
  - [bsd] Added FreeBSD CI support (`#532 <https://github.com/gorakhargosh/watchdog/pull/532>`__)
  - [bsd] Restored full support (`#638 <https://github.com/gorakhargosh/watchdog/pull/638>`__, `#641 <https://github.com/gorakhargosh/watchdog/pull/641>`__)
- deleted patches
  - add-missing-conftest.patch (upstreamed)
* Wed Nov  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in Brownie as it is not needed
* Mon Nov 19 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.3
- Cherry-pick upstream patch to fix testsuite
  + add-missing-conftest.patch
- Update BuildRequires from setup.py
* Thu Aug  9 2018 tchvatal@suse.com
- Remove devel dependency
- Use %%license macro
* Sat Aug 12 2017 jengelh@inai.de
- Specify RPM group more exactly
* Sat Apr 22 2017 aloisio@gmx.com
- Converted to single-spec
- Split docs into separate package
* Fri Mar 11 2016 freitag@opensuse.org
- Update to version 0.8.3
  * Event emitters are no longer started on schedule if Observer is
    not already running.
  Changes from 0.8.0:
  * DirectorySnapshot: methods returning internal stat info replaced
    by mtime, inode and path methods.
  * DirectorySnapshot: walker_callback parameter deprecated.
  no more changelog available upstream
- Fix py compile mtime issue
- use record filelist feature of setup.py to gather proper filelist
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 0.6.0 version:
  * No changelog or NEWS file provided
* Tue Jan 31 2012 saschpe@suse.de
- Initial version
